@@ -1,6 +1,6 @@
 /*****************************************************************************
  *
- * 
+ * $Id: commentcnv.l,v 1.80 2001/03/19 19:27:41 root Exp $
  *
  * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
@@ -20,7 +20,8 @@
 
 class BufStr;
 
-extern void convertCppComments(BufStr *inBuf,BufStr *outBuf);
+extern void convertCppComments(BufStr *inBuf,BufStr *outBuf,
+                               const char *fileName);
 
 #endif
 
