@@ -21,6 +21,7 @@
 "      <xsd:element name=\"includedby\" type=\"incType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"incdepgraph\" type=\"graphType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"invincdepgraph\" type=\"graphType\" minOccurs=\"0\" />\n"
+"      <xsd:element name=\"innerdir\" type=\"refType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"innerfile\" type=\"refType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"innerclass\" type=\"refType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"innernamespace\" type=\"refType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
@@ -61,7 +62,7 @@
 "  <xsd:complexType name=\"compoundRefType\" mixed=\"true\">\n"
 "    <xsd:simpleContent>\n"
 "      <xsd:extension base=\"xsd:string\">\n"
-"        <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
+"        <xsd:attribute name=\"refid\" type=\"xsd:string\" use=\"optional\" />\n"
 "        <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" />\n"
 "        <xsd:attribute name=\"virt\" type=\"DoxVirtualKind\" />\n"
 "      </xsd:extension>\n"
@@ -106,6 +107,7 @@
 "  <xsd:complexType name=\"sectiondefType\">\n"
 "    <xsd:sequence>\n"
 "      <xsd:element name=\"header\" type=\"xsd:string\" minOccurs=\"0\" />\n"
+"      <xsd:element name=\"description\" type=\"descriptionType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"memberdef\" type=\"memberdefType\" maxOccurs=\"unbounded\" />\n"
 "    </xsd:sequence>\n"
 "    <xsd:attribute name=\"kind\" type=\"DoxSectionKind\" />\n"
@@ -118,6 +120,8 @@
 "      <xsd:element name=\"definition\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"argsstring\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"name\" />\n"
+"      <xsd:element name=\"read\" minOccurs=\"0\" />\n"
+"      <xsd:element name=\"write\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"reimplements\" type=\"reimplementType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"reimplementedby\" type=\"reimplementType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"param\" type=\"paramType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
@@ -156,9 +160,9 @@
 "  <xsd:complexType name=\"enumvalueType\" mixed=\"true\">\n"
 "    <xsd:sequence>\n"
 "      <xsd:element name=\"name\" />\n"
+"      <xsd:element name=\"initializer\" type=\"linkedTextType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"briefdescription\" type=\"descriptionType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"detaileddescription\" type=\"descriptionType\" minOccurs=\"0\" />\n"
-"      <xsd:element name=\"initializer\" type=\"linkedTextType\" minOccurs=\"0\" />\n"
 "    </xsd:sequence>\n"
 "    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" />\n"
@@ -212,12 +216,12 @@
 "\n"
 "  <xsd:complexType name=\"linkType\">\n"
 "    <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
-"    <xsd:attribute name=\"external\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"external\" type=\"xsd:string\" use=\"optional\"/>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"listingType\">\n"
 "    <xsd:sequence>\n"
-"      <xsd:element name=\"codeline\" type=\"codelineType\" maxOccurs=\"unbounded\" />\n"
+"      <xsd:element name=\"codeline\" type=\"codelineType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "    </xsd:sequence>\n"
 "  </xsd:complexType>\n"
 "\n"
@@ -524,12 +528,25 @@
 "    <xsd:attribute name=\"langid\" type=\"xsd:string\" /> \n"
 "  </xsd:complexType>\n"
 "\n"
-"  <xsd:group name=\"docParamListGroup\">\n"
+"  <xsd:complexType name=\"docParamListType\">\n"
 "    <xsd:sequence>\n"
-"      <xsd:element name=\"parametername\" type=\"docParamName\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
+"      <xsd:element name=\"parameteritem\" type=\"docParamListItem\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
+"    </xsd:sequence>\n"
+"    <xsd:attribute name=\"kind\" type=\"DoxParamListKind\" /> \n"
+"  </xsd:complexType>\n"
+"\n"
+"  <xsd:complexType name=\"docParamListItem\">\n"
+"    <xsd:sequence>\n"
+"      <xsd:element name=\"parameternamelist\" type=\"docParamNameList\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"parameterdescription\" type=\"descriptionType\" />\n"
 "    </xsd:sequence>\n"
-"  </xsd:group>\n"
+"  </xsd:complexType>\n"
+"\n"
+"  <xsd:complexType name=\"docParamNameList\">\n"
+"    <xsd:sequence>\n"
+"      <xsd:element name=\"parametername\" type=\"docParamName\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
+"    </xsd:sequence>\n"
+"  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docParamName\">\n"
 "    <xsd:simpleContent>\n"
@@ -539,13 +556,6 @@
 "    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
-"  <xsd:complexType name=\"docParamListType\">\n"
-"    <xsd:sequence>\n"
-"      <xsd:group ref=\"docParamListGroup\" maxOccurs=\"unbounded\" />\n"
-"    </xsd:sequence>\n"
-"    <xsd:attribute name=\"kind\" type=\"DoxParamListKind\" /> \n"
-"  </xsd:complexType>\n"
-"\n"
 "  <xsd:complexType name=\"docXRefSectType\">\n"
 "    <xsd:sequence>\n"
 "      <xsd:element name=\"xreftitle\" type=\"xsd:string\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
@@ -644,6 +654,7 @@
 "      <xsd:enumeration value=\"group\" />\n"
 "      <xsd:enumeration value=\"page\" />\n"
 "      <xsd:enumeration value=\"example\" />\n"
+"      <xsd:enumeration value=\"dir\" />\n"
 "    </xsd:restriction>\n"
 "  </xsd:simpleType>\n"
 "\n"
