@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * 
+ * $Id: entry.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
  * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
@@ -70,6 +70,8 @@ Entry::Entry(const Entry &e)
   docFile     = e.docFile.copy();
   relates     = e.relates.copy();
   relatesDup  = e.relatesDup;
+  read        = e.read.copy();
+  write       = e.write.copy();
   brief       = e.brief.copy();
   briefLine   = e.briefLine;
   briefFile   = e.briefFile.copy();
