@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * 
+ * $Id: $
  *
  *
  * Copyright (C) 1997-2004 by Dimitri van Heesch.
@@ -111,8 +111,8 @@ class ManDocVisitor : public DocVisitor
     void visitPost(DocSecRefItem *);
     void visitPre(DocSecRefList *);
     void visitPost(DocSecRefList *);
-    void visitPre(DocLanguage *);
-    void visitPost(DocLanguage *);
+    //void visitPre(DocLanguage *);
+    //void visitPost(DocLanguage *);
     void visitPre(DocParamSect *);
     void visitPost(DocParamSect *);
     void visitPre(DocParamList *);
