@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * 
+ * $Id: namespacedef.h,v 1.18 2001/03/19 19:27:41 root Exp $
  *
  * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
@@ -38,7 +38,8 @@ class NamespaceDef : public Definition
 {
   public:
     NamespaceDef(const char *defFileName,int defLine,
-                 const char *name,const char *ref=0);
+                 const char *name,const char *ref=0,
+                 const char *refFile=0);
    ~NamespaceDef();
     DefType definitionType() { return TypeNamespace; }
     QCString getOutputFileBase() const;
@@ -162,6 +163,7 @@ class NamespaceSDict : public SDict<NamespaceDef>
                     ((NamespaceDef *)item2)->name()
                    );
     }
+    void writeDeclaration(OutputList &ol,bool localName=FALSE);
 };
 
 
